@@ -2,6 +2,8 @@ resizer = {};
 
 resizer.currentMode = "";
 
+resizer.debug = false;
+
 resizer.run = function(){
     var browserWidth = window.innerWidth || document.documentElement.clientWidth;
     var jqueryWidth = $(window).width()
@@ -32,7 +34,12 @@ resizer.run = function(){
         $("body").addClass(mode);
         resizer.onResize();
     }
-    //resizer.refreshDebugDiv();
+    
+    if (resizer.debug === true)
+    {
+        resizer.refreshDebugDiv();
+    }
+    
 };
 
 resizer.onResize = function ()
@@ -44,18 +51,21 @@ resizer.refreshDebugDiv = function ()
 {
     var browserWidth = window.innerWidth || document.documentElement.clientWidth;
     var jqueryWidth = $(window).width()
-    var width = Math.max(jqueryWidth, browserWidth);   
-    if ($("#debug").length == 1)
+    var width = Math.max(jqueryWidth, browserWidth);
+    if (resizer.debug === true)  
     {
-        $("#debug").text(width);
-        //$("#debug").text(resizer.currentMode);
-        //$("#debug").text($.browser.webkit);
-    }
-    else
-    {
-        $("body").append('<div id="debug"></div>');
-        //$("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(width)
-        //$("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(resizer.currentMode)
+        if ($("#debug").length == 1)
+        {
+            $("#debug").text(width);
+            //$("#debug").text(resizer.currentMode);
+            //$("#debug").text($.browser.webkit);
+        }
+        else
+        {
+            $("body").append('<div id="debug"></div>');
+            $("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(width)
+            //$("#debug").css({'position':'fixed', 'right':'0', 'top':'0', 'background-color':'#000', 'color':'#fff', 'width':'50px', 'height':'20px', 'font-size':'11px'}).text(resizer.currentMode)
+        }
     }
 }
 
